@@ -1,4 +1,4 @@
-package News::Pictures;perl
+package News::Pictures;
 
 use warnings;
 #use strict;
@@ -11,11 +11,11 @@ News::Pictures - The great new News::Pictures!
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 =head1 SYNOPSIS
